#!/usr/bin/python
# -*- coding: utf-8 -*-   
#
#  __init__.py
#  
#
#  Created by TVA on 1/25/18.
#  Copyright (c) 2018 parseyml. All rights reserved.
#
from parse_yml import main

__all__ = ['main', 'travel_and_print_env']